/***********************************************************************/
/* Open Visualization Data Explorer                                    */
/* (C) Copyright IBM Corp. 1989,1999                                   */
/* ALL RIGHTS RESERVED                                                 */
/* This code licensed under the                                        */
/*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
/***********************************************************************/
#define CIRCLE4PTS 4 
#define CIRCLE4TRS 2 
static Point points[CIRCLE4PTS] = {
 { -0.0000000437F,      1.0000000000F,      0.0000000000F },
 { -1.0000000000F,     -0.0000000874F,      0.0000000000F },
 {  0.0000000119F,     -1.0000000000F,      0.0000000000F },
 {  1.0000000000F,      0.0000000000F,      0.0000000000F }
};
static Triangle triangles[] = {
  {  0,     1,     2 }, 
  {  0,     2,     3 }
};
